Mesh simplification and decimation algorithms
This crate provides algorithms for reducing mesh complexity while preserving important geometric features:
- Quadric error decimation
- Edge collapse algorithms
- Clustering-based simplification
Re-exports
pub use quadric_error::*;pub use edge_collapse::*;pub use clustering::*;pub use progressive::*;
Modules
- clustering
- Clustering-based mesh simplification
- edge_
collapse - Edge collapse simplification
- progressive
- Progressive mesh implementation based on Hoppe (1996)
- quadric_
error - Quadric error decimation
Traits
- Mesh
Simplifier - Simplify a mesh by reducing the number of faces/vertices