RepresentativeStrategy

Enum RepresentativeStrategy 

pub enum RepresentativeStrategy {
    Centroid,
    WeightedAverage,
    MinimumError,
}
Strategy for selecting the representative vertex within a cluster.

Variants



Centroid

Arithmetic mean of all vertex positions in the cluster.



WeightedAverage

Weighted average using vertex valence (number of adjacent faces).



MinimumError

Position that minimizes the summed quadric error for the cluster.